import * as i0 from '@angular/core';
import { inject, ElementRef, EventEmitter, Directive, Input, Output, Component } from '@angular/core';
import { mergeDeep, naturalFieldComparator, buildChart, buildSingleSerieChart } from '@oneteme/jquery-core';
import ApexCharts from 'apexcharts';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';

const ICONS = {
    previous: `<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 -960 960 960" style="width: 15px; height: 15px">
  <path d="M400-80 0-480l400-400 71 71-329 329 329 329-71 71Z"/>
  </svg>`,
    next: `<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 -960 960 960" style="width: 15px; height: 15px"><path d="m321-80-71-71 329-329-329-329 71-71 400 400L321-80Z"/></svg>`,
    pivot: `<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 -960 960 960" style="width: 15px; height: 15px"><path d="M400-640v-200h360q33 0 56.5 23.5T840-760v120H400ZM200-120q-33 0-56.5-23.5T120-200v-360h200v440H200Zm-80-520v-120q0-33 23.5-56.5T200-840h120v200H120ZM520-80 360-240l160-160 56 56-62 64h86q33 0 56.5-23.5T680-360v-88l-64 64-56-56 160-160 160 160-56 56-64-64v88q0 66-47 113t-113 47h-86l62 64-56 56Z"/></svg>`,
};

function customIcons(event, canPivot) {
    var customIcons = [{
            icon: ICONS.previous,
            title: 'Graphique précédent',
            class: 'custom-icon',
            click: function (chart, options, e) {
                event("previous");
            }
        },
        {
            icon: ICONS.next,
            title: 'Graphique suivant',
            class: 'custom-icon',
            click: function (chart, options, e) {
                event("next");
            }
        }];
    if (canPivot) {
        customIcons.push({
            icon: ICONS.pivot,
            title: 'Pivot',
            class: 'custom-icon',
            click: function (chart, options, e) {
                event("pivot");
            }
        });
    }
    return customIcons;
}
function getType(commonChart) {
    if (commonChart.series.length && commonChart.series[0].data.length) {
        if (commonChart.continue) {
            var x = commonChart.series[0].data[0].x;
            return x instanceof Date ? 'datetime' : typeof x == 'number' ? 'numeric' : 'category';
        }
        else {
            var categ = commonChart.categories[0];
            return categ instanceof Date ? 'datetime' : typeof categ == 'number' ? 'numeric' : 'category';
        }
    }
    return 'datetime';
}

class BarChartDirective {
    constructor() {
        this.el = inject(ElementRef);
        this._chartConfig = {};
        this._options = {
            chart: {
                type: 'bar'
            },
            series: []
        };
        this.canPivot = true;
        this.isLoading = false;
        this.customEvent = new EventEmitter();
    }
    updateConfig() {
        let that = this;
        this._chartConfig = this.config;
        mergeDeep(this._options, {
            chart: {
                height: this._chartConfig.height ?? '100%',
                width: this._chartConfig.width ?? '100%',
                stacked: this._chartConfig.stacked,
                toolbar: {
                    show: true,
                    tools: {
                        download: false,
                        selection: false,
                        zoom: false,
                        zoomin: false,
                        zoomout: false,
                        pan: false,
                        reset: false,
                        customIcons: customIcons((arg) => that.customEvent.emit(arg), this.canPivot)
                    }
                },
                events: {
                    mouseMove: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "visible" : null;
                    },
                    mouseLeave: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "hidden" : null;
                    }
                }
            },
            title: {
                text: this._chartConfig.title
            },
            subtitle: {
                text: this._chartConfig.subtitle
            },
            xaxis: {
                title: {
                    text: this._chartConfig.xtitle
                }
            },
            yaxis: {
                title: {
                    text: this._chartConfig.ytitle
                }
            }
        }, this.type == 'bar' ? {
            plotOptions: {
                bar: {
                    horizontal: true
                }
            }
        } : {}, this._chartConfig.options);
    }
    updateData() {
        var data = [...this.data];
        if (this.type == 'funnel') {
            data = data.sort(naturalFieldComparator('asc', this._chartConfig.series[0].data.y));
        }
        else if (this.type == 'pyramid') {
            data = data.sort(naturalFieldComparator('desc', this._chartConfig.series[0].data.y));
        }
        var commonChart = buildChart(data, { ...this._chartConfig, pivot: !this.canPivot ? false : this._chartConfig.pivot });
        mergeDeep(this._options, { series: commonChart.series.map(s => ({ data: s.data, name: s.name, color: s.color, group: s.stack })), xaxis: { type: getType(commonChart), categories: commonChart.categories || [] } });
    }
    updateLoading() {
        mergeDeep(this._options, {
            noData: {
                text: this.isLoading ? 'Loading...' : 'Aucune donnée'
            }
        });
    }
    ngOnChanges(changes) {
        if (this.type && this.config && this.data) {
            if (changes.isLoading) {
                this.updateLoading();
            }
            if (changes.config) {
                this.updateConfig();
            }
            if (changes.config || changes.data) {
                this.updateData();
            }
            this.updateChart();
        }
    }
    ngOnDestroy() {
        if (this._chart) {
            this._chart.destroy();
        }
    }
    updateChart() {
        if (this._chart) {
            this._chart.destroy();
        }
        this.createChart();
        this.render();
    }
    createChart() {
        this._chart = new ApexCharts(this.el.nativeElement, this._options);
    }
    // updateOptions() {
    //   this._chart.resetSeries();
    //   if (this._options.chart.id) {
    //     ApexCharts.exec(this._options.chart.id, 'updateOptions', this._options);
    //   } else {
    //     this._chart.updateOptions(this._options, false, false);
    //   }
    // }
    render() {
        this._chart.render();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BarChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: BarChartDirective, isStandalone: true, selector: "[bar-chart]", inputs: { type: "type", config: "config", data: "data", canPivot: "canPivot", isLoading: "isLoading" }, outputs: { customEvent: "customEvent" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BarChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[bar-chart]'
                }]
        }], propDecorators: { type: [{
                type: Input,
                args: [{ alias: 'type', required: true }]
            }], config: [{
                type: Input,
                args: [{ alias: 'config', required: true }]
            }], data: [{
                type: Input,
                args: [{ required: true }]
            }], canPivot: [{
                type: Input
            }], isLoading: [{
                type: Input
            }], customEvent: [{
                type: Output
            }] } });

class LineChartDirective {
    constructor() {
        this.el = inject(ElementRef);
        this._chartConfig = {};
        this._options = {
            chart: {
                type: 'line'
            },
            series: []
        };
        this.isLoading = false;
        this.customEvent = new EventEmitter();
    }
    ngOnDestroy() {
        if (this._chart) {
            this._chart.destroy();
        }
    }
    ngOnChanges(changes) {
        if (this.type && this.config && this.data) {
            if (changes.type) {
                this.updateType();
            }
            if (changes.isLoading) {
                this.updateLoading();
            }
            if (changes.config) {
                this.updateConfig();
            }
            if (changes.config || changes.data) {
                this.updateData();
            }
            this.updateChart();
        }
    }
    updateType() {
        mergeDeep(this._options, { chart: { type: this.type } });
    }
    updateConfig() {
        let that = this;
        this._chartConfig = this.config;
        mergeDeep(this._options, {
            chart: {
                height: this._chartConfig.height ?? '100%',
                width: this._chartConfig.width ?? '100%',
                stacked: this._chartConfig.stacked,
                toolbar: {
                    show: true,
                    tools: {
                        download: false,
                        selection: false,
                        zoom: false,
                        zoomin: false,
                        zoomout: false,
                        pan: false,
                        reset: false,
                        customIcons: customIcons(arg => that.customEvent.emit(arg), true)
                    }
                },
                events: {
                    mouseMove: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "visible" : null;
                    },
                    mouseLeave: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "hidden" : null;
                    }
                }
            },
            title: {
                text: this._chartConfig.title
            },
            subtitle: {
                text: this._chartConfig.subtitle
            },
            xaxis: {
                title: {
                    text: this._chartConfig.xtitle
                }
            },
            yaxis: {
                title: {
                    text: this._chartConfig.ytitle
                }
            }
        }, this._chartConfig.options);
    }
    updateData() {
        var commonChart = buildChart(this.data, { ...this._chartConfig, continue: true }, null);
        mergeDeep(this._options, { series: commonChart.series, xaxis: { type: getType(commonChart) } });
    }
    updateLoading() {
        mergeDeep(this._options, {
            noData: {
                text: this.isLoading ? 'Loading...' : 'Aucune donnée'
            }
        });
    }
    updateChart() {
        if (this._chart) {
            this._chart.destroy();
        }
        this.createChart();
        this.render();
    }
    createChart() {
        this._chart = new ApexCharts(this.el.nativeElement, this._options);
    }
    // updateOptions() {
    //     this._chart.resetSeries();
    //     if (this._options.chart.id) {
    //         ApexCharts.exec(this._options.chart.id, 'updateOptions', this._options);
    //     } else {
    //         this._chart.updateOptions(this._options, false, false);
    //     }
    // }
    render() {
        this._chart.render();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LineChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: LineChartDirective, isStandalone: true, selector: "[line-chart]", inputs: { type: "type", config: "config", data: "data", isLoading: "isLoading" }, outputs: { customEvent: "customEvent" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LineChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[line-chart]'
                }]
        }], propDecorators: { type: [{
                type: Input,
                args: [{ required: true }]
            }], config: [{
                type: Input,
                args: [{ required: true }]
            }], data: [{
                type: Input,
                args: [{ required: true }]
            }], isLoading: [{
                type: Input
            }], customEvent: [{
                type: Output
            }] } });

class PieChartDirective {
    constructor() {
        this.el = inject(ElementRef);
        this.typeMapping = {
            'pie': 'pie',
            'donut': 'donut',
            'radial': 'radialBar',
            'polar': 'polarArea',
            'radar': 'radar'
        };
        this._chartConfig = {};
        this._options = {
            chart: {
                type: 'pie'
            },
            series: []
        };
        this.isLoading = false;
        this.customEvent = new EventEmitter();
    }
    ngOnDestroy() {
        if (this._chart) {
            this._chart.destroy();
        }
    }
    ngOnChanges(changes) {
        if (this.type && this.config && this.data) {
            if (changes.type) {
                this.updateType();
            }
            if (changes.isLoading) {
                this.updateLoading();
            }
            if (changes.config) {
                this.updateConfig();
            }
            if (changes.config || changes.data) {
                this.updateData();
            }
            this.updateChart();
        }
    }
    updateType() {
        mergeDeep(this._options, { chart: { type: this.typeMapping[this.type] } });
    }
    updateConfig() {
        let that = this;
        this._chartConfig = this.config;
        mergeDeep(this._options, {
            chart: {
                height: this._chartConfig.height ?? '100%',
                width: this._chartConfig.width ?? '100%',
                toolbar: {
                    show: true,
                    tools: {
                        download: false,
                        selection: false,
                        zoom: false,
                        zoomin: false,
                        zoomout: false,
                        pan: false,
                        reset: false,
                        customIcons: customIcons(arg => that.customEvent.emit(arg), true)
                    }
                },
                events: {
                    mouseMove: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "visible" : null;
                    },
                    mouseLeave: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "hidden" : null;
                    }
                }
            },
            title: {
                text: this._chartConfig.title
            },
            subtitle: {
                text: this._chartConfig.subtitle
            },
            xaxis: {
                title: {
                    text: this._chartConfig.xtitle
                }
            },
            yaxis: {
                title: {
                    text: this._chartConfig.ytitle
                }
            },
        }, this._chartConfig.options);
    }
    updateData() {
        var chartConfig = { ...this._chartConfig, continue: false };
        var commonChart = this.data.length != 1 && this.type == 'radar' ? buildChart(this.data, chartConfig, null) : buildSingleSerieChart(this.data, chartConfig, null);
        var colors = commonChart.series.filter(d => d.color).map(d => d.color);
        mergeDeep(this._options, { series: this.data.length != 1 && this.type == 'radar' ? commonChart.series : this.type == 'radar' ? [{ name: 'Series 1', data: commonChart.series.flatMap(s => s.data.filter(d => d != null)) }] : commonChart.series.flatMap(s => s.data.filter(d => d != null)), labels: commonChart.categories || [], colors: colors || [] });
    }
    updateLoading() {
        mergeDeep(this._options, {
            noData: {
                text: this.isLoading ? 'Loading...' : 'Aucune donnée'
            }
        });
    }
    updateChart() {
        if (this._chart) {
            this._chart.destroy();
        }
        this.createChart();
        this.render();
    }
    createChart() {
        this._chart = new ApexCharts(this.el.nativeElement, this._options);
    }
    // updateOptions() {
    //     this._chart.resetSeries();
    //     if (this._options.chart.id) {
    //         ApexCharts.exec(this._options.chart.id, 'updateOptions', this._options);
    //     } else {
    //         this._chart.updateOptions(this._options, false, false);
    //     }
    // }
    render() {
        this._chart.render();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PieChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: PieChartDirective, isStandalone: true, selector: "[pie-chart]", inputs: { type: "type", config: "config", data: "data", isLoading: "isLoading" }, outputs: { customEvent: "customEvent" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PieChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[pie-chart]'
                }]
        }], propDecorators: { type: [{
                type: Input,
                args: [{ required: true }]
            }], config: [{
                type: Input,
                args: [{ required: true }]
            }], data: [{
                type: Input,
                args: [{ required: true }]
            }], isLoading: [{
                type: Input
            }], customEvent: [{
                type: Output
            }] } });

class TreemapChartDirective {
    constructor() {
        this.el = inject(ElementRef);
        this._chartConfig = {};
        this._options = {
            chart: {
                type: 'treemap'
            },
            series: []
        };
        this.isLoading = false;
        this.customEvent = new EventEmitter();
    }
    ngOnChanges(changes) {
        if (this.type && this.config && this.data) {
            if (changes.type) {
                this.updateType();
            }
            if (changes.isLoading) {
                this.updateLoading();
            }
            if (changes.config) {
                this.updateConfig();
            }
            if (changes.config || changes.data) {
                this.updateData();
            }
            this.updateChart();
        }
    }
    ngOnDestroy() {
        if (this._chart) {
            this._chart.destroy();
        }
    }
    updateType() {
        mergeDeep(this._options, { chart: { type: this.type } });
    }
    updateConfig() {
        let that = this;
        this._chartConfig = this.config;
        mergeDeep(this._options, {
            chart: {
                height: this._chartConfig.height ?? '100%',
                width: this._chartConfig.width ?? '100%',
                toolbar: {
                    show: true,
                    tools: {
                        download: false,
                        selection: false,
                        zoom: false,
                        zoomin: false,
                        zoomout: false,
                        pan: false,
                        reset: false,
                        customIcons: customIcons(arg => that.customEvent.emit(arg), true)
                    }
                },
                events: {
                    mouseMove: function (e, c, config) { that.el.nativeElement.querySelector('.apexcharts-toolbar').style.visibility = "visible"; },
                    mouseLeave: function (e, c, config) { that.el.nativeElement.querySelector('.apexcharts-toolbar').style.visibility = "hidden"; }
                }
            },
            title: {
                text: this._chartConfig.title
            },
            subtitle: {
                text: this._chartConfig.subtitle
            },
            xaxis: {
                title: {
                    text: this._chartConfig.xtitle
                }
            },
            yaxis: {
                title: {
                    text: this._chartConfig.ytitle
                }
            }
        }, this._chartConfig.options);
    }
    updateData() {
        var commonChart = buildChart(this.data, { ...this._chartConfig, continue: true }, null);
        mergeDeep(this._options, { series: commonChart.series, xaxis: { type: getType(commonChart) } });
    }
    updateLoading() {
        mergeDeep(this._options, {
            noData: {
                text: this.isLoading ? 'Loading...' : 'Aucune donnée'
            }
        });
    }
    updateChart() {
        if (this._chart) {
            this._chart.destroy();
        }
        this.createChart();
        this.render();
    }
    createChart() {
        this._chart = new ApexCharts(this.el.nativeElement, this._options);
    }
    render() {
        this._chart.render();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TreemapChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: TreemapChartDirective, isStandalone: true, selector: "[treemap-chart]", inputs: { type: "type", config: "config", data: "data", isLoading: "isLoading" }, outputs: { customEvent: "customEvent" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TreemapChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[treemap-chart]'
                }]
        }], propDecorators: { type: [{
                type: Input,
                args: [{ required: true }]
            }], config: [{
                type: Input,
                args: [{ required: true }]
            }], data: [{
                type: Input,
                args: [{ required: true }]
            }], isLoading: [{
                type: Input
            }], customEvent: [{
                type: Output
            }] } });

class TestChartDirective {
    constructor() {
        this.el = inject(ElementRef);
    }
    ngAfterViewInit() {
        var options = {
            series: [{
                    name: 'Website Blog',
                    type: 'column',
                    data: [440, 505, 414, 671, 227, 413, 201, 352, 752, 320, 257, 160]
                }, {
                    name: 'Social Media',
                    type: 'area',
                    data: [23, 42, 35, 27, 43, 22, 17, 31, 22, 22, 12, 16]
                }],
            chart: {
                height: 350,
                type: 'area',
            },
            dataLabels: {
                enabled: true,
                enabledOnSeries: [1]
            },
            labels: ['01 Jan 2001', '02 Jan 2001', '03 Jan 2001', '04 Jan 2001', '05 Jan 2001', '06 Jan 2001', '07 Jan 2001', '08 Jan 2001', '09 Jan 2001', '10 Jan 2001', '11 Jan 2001', '12 Jan 2001'],
            xaxis: {
                type: 'datetime'
            },
            yaxis: [{
                    title: {
                        text: 'Website Blog',
                    },
                }, {
                    opposite: true,
                    title: {
                        text: 'Social Media'
                    }
                }]
        };
        this._chart = new ApexCharts(this.el.nativeElement, options);
        this._chart.render();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TestChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: TestChartDirective, isStandalone: true, selector: "[test-chart]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TestChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[test-chart]'
                }]
        }] });

class RangeChartDirective {
    constructor() {
        this.el = inject(ElementRef);
        this._chartConfig = {};
        this._options = {
            chart: {
                type: 'rangeArea'
            },
            series: []
        };
        this.canPivot = true;
        this.isLoading = false;
        this.customEvent = new EventEmitter();
    }
    ngOnDestroy() {
        if (this._chart) {
            this._chart.destroy();
        }
    }
    ngOnChanges(changes) {
        if (this.type && this.config && this.data) {
            if (changes.type) {
                this.updateType();
            }
            if (changes.isLoading) {
                this.updateLoading();
            }
            if (changes.config) {
                this.updateConfig();
            }
            if (changes.config || changes.data) {
                this.updateData();
            }
            this.updateChart();
        }
    }
    updateType() {
        mergeDeep(this._options, { chart: { type: this.type == 'rangeColumn' ? 'rangeBar' : this.type } });
    }
    updateConfig() {
        let that = this;
        this._chartConfig = this.config;
        mergeDeep(this._options, {
            chart: {
                height: this._chartConfig.height ?? '100%',
                width: this._chartConfig.width ?? '100%',
                toolbar: {
                    show: true,
                    tools: {
                        download: false,
                        selection: false,
                        zoom: false,
                        zoomin: false,
                        zoomout: false,
                        pan: false,
                        reset: false,
                        customIcons: customIcons(arg => that.customEvent.emit(arg), true)
                    }
                },
                events: {
                    mouseMove: function (e, c, config) { that.el.nativeElement.querySelector('.apexcharts-toolbar').style.visibility = "visible"; },
                    mouseLeave: function (e, c, config) { that.el.nativeElement.querySelector('.apexcharts-toolbar').style.visibility = "hidden"; }
                }
            },
            title: {
                text: this._chartConfig.title
            },
            subtitle: {
                text: this._chartConfig.subtitle
            },
            xaxis: {
                title: {
                    text: this._chartConfig.xtitle
                }
            },
            yaxis: {
                title: {
                    text: this._chartConfig.ytitle
                }
            }
        }, this.type == 'rangeBar' ? {
            plotOptions: {
                bar: {
                    horizontal: true
                }
            }
        } : {}, this._chartConfig.options);
    }
    updateData() {
        var commonChart = buildChart(this.data, { ...this._chartConfig, continue: true, pivot: !this.canPivot ? false : this._chartConfig.pivot }, null);
        mergeDeep(this._options, { series: commonChart.series, xaxis: { type: getType(commonChart) } });
    }
    updateLoading() {
        mergeDeep(this._options, {
            noData: {
                text: this.isLoading ? 'Loading...' : 'Aucune donnée'
            }
        });
    }
    updateChart() {
        if (this._chart) {
            this._chart.destroy();
        }
        this.createChart();
        this.render();
    }
    createChart() {
        this._chart = new ApexCharts(this.el.nativeElement, this._options);
    }
    render() {
        this._chart.render();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RangeChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: RangeChartDirective, isStandalone: true, selector: "[range-chart]", inputs: { type: "type", config: "config", data: "data", canPivot: "canPivot", isLoading: "isLoading" }, outputs: { customEvent: "customEvent" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RangeChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[range-chart]'
                }]
        }], propDecorators: { type: [{
                type: Input,
                args: [{ required: true }]
            }], config: [{
                type: Input,
                args: [{ required: true }]
            }], data: [{
                type: Input,
                args: [{ required: true }]
            }], canPivot: [{
                type: Input
            }], isLoading: [{
                type: Input
            }], customEvent: [{
                type: Output
            }] } });

class ChartComponent {
    constructor() {
        this._charts = {
            'pie': ['pie', 'donut', 'polar', 'radar'],
            'donut': ['pie', 'donut', 'polar', 'radar'],
            'polar': ['pie', 'donut', 'polar', 'radar'],
            'radar': ['pie', 'donut', 'polar', 'radar'],
            'line': ['line', 'area'],
            'area': ['line', 'area'],
            'bar': ['bar', 'column', 'heatmap', 'treemap'],
            'column': ['bar', 'column', 'heatmap', 'treemap'],
            'heatmap': ['bar', 'column', 'heatmap', 'treemap'],
            'treemap': ['bar', 'column', 'heatmap', 'treemap'],
            'funnel': ['funnel', 'pyramid'],
            'pyramid': ['funnel', 'pyramid'],
            'rangeArea': ['rangeArea', 'rangeBar', 'rangeColumn'],
            'rangeBar': ['rangeArea', 'rangeBar', 'rangeColumn'],
            'rangeColumn': ['rangeArea', 'rangeBar', 'rangeColumn']
        };
    }
    change(event) {
        if (!this.initialType) {
            this.initialType = this.type;
        }
        let charts = this._charts[this.initialType];
        let indexOf = charts.indexOf(this.type);
        if (indexOf != -1) {
            if (event == 'previous') {
                this.type = indexOf == 0 ? charts[charts.length - 1] : charts[indexOf - 1];
                return;
            }
            if (event == 'next') {
                this.type = indexOf == charts.length - 1 ? charts[0] : charts[indexOf + 1];
                return;
            }
        }
        if (event == 'pivot') {
            this.config = this.config.pivot ? { ...this.config, pivot: false } : { ...this.config, pivot: true };
            return;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ChartComponent, isStandalone: true, selector: "chart", inputs: { type: "type", config: "config", data: "data", isLoading: "isLoading" }, ngImport: i0, template: "<div [ngSwitch]=\"type\">\n    <div *ngSwitchCase=\"'line'\" line-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'area'\" line-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'pie'\" pie-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'donut'\" pie-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'polar'\" pie-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'radial'\" pie-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div> \n    <div *ngSwitchCase=\"'radar'\" pie-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'bar'\" bar-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'column'\" bar-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'funnel'\" bar-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" [canPivot]=\"false\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'pyramid'\" bar-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" [canPivot]=\"false\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'treemap'\" treemap-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'heatmap'\" treemap-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'rangeArea'\" range-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" [canPivot]=\"false\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'rangeBar'\" range-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'rangeColumn'\" range-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n</div>", dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i1.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "directive", type: BarChartDirective, selector: "[bar-chart]", inputs: ["type", "config", "data", "canPivot", "isLoading"], outputs: ["customEvent"] }, { kind: "directive", type: LineChartDirective, selector: "[line-chart]", inputs: ["type", "config", "data", "isLoading"], outputs: ["customEvent"] }, { kind: "directive", type: PieChartDirective, selector: "[pie-chart]", inputs: ["type", "config", "data", "isLoading"], outputs: ["customEvent"] }, { kind: "directive", type: RangeChartDirective, selector: "[range-chart]", inputs: ["type", "config", "data", "canPivot", "isLoading"], outputs: ["customEvent"] }, { kind: "directive", type: TreemapChartDirective, selector: "[treemap-chart]", inputs: ["type", "config", "data", "isLoading"], outputs: ["customEvent"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartComponent, decorators: [{
            type: Component,
            args: [{ standalone: true, imports: [
                        CommonModule,
                        BarChartDirective,
                        LineChartDirective,
                        PieChartDirective,
                        RangeChartDirective,
                        TreemapChartDirective
                    ], selector: 'chart', template: "<div [ngSwitch]=\"type\">\n    <div *ngSwitchCase=\"'line'\" line-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'area'\" line-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'pie'\" pie-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'donut'\" pie-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'polar'\" pie-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'radial'\" pie-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div> \n    <div *ngSwitchCase=\"'radar'\" pie-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'bar'\" bar-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'column'\" bar-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'funnel'\" bar-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" [canPivot]=\"false\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'pyramid'\" bar-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" [canPivot]=\"false\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'treemap'\" treemap-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'heatmap'\" treemap-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'rangeArea'\" range-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" [canPivot]=\"false\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'rangeBar'\" range-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n    <div *ngSwitchCase=\"'rangeColumn'\" range-chart [type]=\"type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n</div>" }]
        }], propDecorators: { type: [{
                type: Input
            }], config: [{
                type: Input
            }], data: [{
                type: Input
            }], isLoading: [{
                type: Input
            }] } });

/*
 * Public API Surface of jquery-apexcharts
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BarChartDirective, ChartComponent, LineChartDirective, PieChartDirective, RangeChartDirective, TestChartDirective, TreemapChartDirective };
//# sourceMappingURL=oneteme-jquery-apexcharts.mjs.map
